@@ -81,26 +81,35 @@ class Base(ABC):
             de los parametros.
         """
         # Parametros
-        paramsInject = {}
+        paramsInject = []
+
+        # Heders
+        HEADERS = data["headers"]
+
+        # Auth
+        AUTH = HEADERS.get("Authorizacion", None)
+
+        # En caso de que se indique con otro nombre
+        if AUTH is None:
+            AUTH = HEADERS.get("Authorization", None)
 
         # Seleccion de parametros
         for i in paramList:
             if i == 'data':
-                paramsInject.update({i: data.get('data')})
+                paramsInject.append(data.get('data'))
             elif i == 'filters':
                 data_params = self.__transformFilter(
                     getItemBy('metadata.filters', data))
                 data_params = {} if data_params is None else data_params
-                paramsInject.update({
-                    i: data_params,
-                })
+                paramsInject.append(data_params)
+            elif i == 'authorization':
+                paramsInject.append(AUTH)
             elif i == 'authorizacion':
-                paramsInject.update({i: data["headers"]["Authorizacion"]})
+                paramsInject.append(AUTH)
             elif i == 'uuid':
-                paramsInject.update({i: getItemBy('metadata.uuid', data)})
+                paramsInject.append(getItemBy('metadata.uuid', data))
             elif i == 'response':
-                paramsInject.update(
-                    {i: getItemBy('response.data.response', data)})
+                paramsInject.append(getItemBy('response.data.response', data))
 
         return paramsInject
 
