@@ -21,7 +21,7 @@ class Worker(Base):
             paramsInject = self.getParams(request, params)
 
             # Ejecutar la funciona final
-            RESP = fnc(**paramsInject)
+            RESP = fnc(*paramsInject)
             # Regresar la respuesta con el formato correcto
             return self.formatResponse(request, RESP)
         except ErrorMs as err:
